@@ -57,12 +57,6 @@ pref("calendar.alarms.todoalarmunit", "minutes");
 pref("calendar.invitations.autorefresh.enabled", true);
 pref("calendar.invitations.autorefresh.timeout", 3);
 
-// iTIP compatibility send mode
-// 0 -- Outlook 2003 and following with text/plain and application/ics (default)
-// 1 -- all Outlook, but no text/plain nor application/ics
-// We may extend the compat mode if necessary.
-pref("calendar.itip.compatSendMode", 0);
-
 // whether "notify" is checked by default when creating new events/todos with attendees
 pref("calendar.itip.notify", true);
 
@@ -81,6 +75,9 @@ pref("calendar.itip.notifyDelegatorOnReply", true);
 // whether to prefix the subject field for email invitation invites or updates.
 pref("calendar.itip.useInvitationSubjectPrefixes", true);
 
+// whether separate invitation actions to more separate buttons or integrate into few buttons
+pref("calendar.itip.separateInvitationButtons", true);
+
 // whether CalDAV (experimental) scheduling is enabled or not.
 pref("calendar.caldav.sched.enabled", false);
 
@@ -133,7 +130,7 @@ pref("mousewheel.withshiftkey.action", 0);
 // Disable use of worker threads. Restart needed.
 pref("calendar.threading.disabled", false);
 
-// The maximum time in microseconds that a cal.forEach event can take (soft limit).
+// The maximum time in microseconds that a cal.iterate.forEach event can take (soft limit).
 pref("calendar.threading.latency ", 250);
 
 // Enable support for multiple realms on one server with the payoff that you
@@ -141,7 +138,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/5.4.9");
+pref("calendar.useragent.extra", "Lightning/6.2");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -159,10 +156,13 @@ pref("calendar.item.editInTab", false);
 // Edit events and tasks in the new (HTML-based) UI for tabs and windows
 pref("calendar.item.useNewItemUI", false);
 
+// Always use the currently selected calendar as target for paste operations
+pref("calendar.paste.intoSelectedCalendar", false);
+
 // Backend to use. false: libical, true: ical.js
-//@line 166 "/var/tmp/portage/mail-client/thunderbird-52.9.0/work/thunderbird-52.9.0/calendar/lightning/content/lightning.js"
+//@line 166 "/var/tmp/portage/mail-client/thunderbird-60.0/work/thunderbird-60.0/comm/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 168 "/var/tmp/portage/mail-client/thunderbird-52.9.0/work/thunderbird-52.9.0/calendar/lightning/content/lightning.js"
+//@line 168 "/var/tmp/portage/mail-client/thunderbird-60.0/work/thunderbird-60.0/comm/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
